@@ -66,10 +66,10 @@ class OrionXExchange(ExchangeService):
             logging.debug(err)
             raise err
 
-    async def get_open_orders_by_market(self, market: str):
+    async def get_open_orders_by_market(self, market: str, selling: str):
         try:
             async with aiohttp.ClientSession() as session:
-                response = await self.client.get_open_orders_by_market(market=market, session=session)
+                response = await self.client.get_open_orders_by_market(market=market, selling=selling, session=session)
             logging.info(response)
             return response
         except Exception as err:
@@ -86,11 +86,12 @@ class OrionXExchange(ExchangeService):
             logging.debug(err)
             raise err
 
-    async def close_orders_by_market(self, market: str):
+    async def close_orders_by_market(self, market: str, selling: str):
         try:
             async with aiohttp.ClientSession() as session:
-                response = await self.client.close_orders_by_market(market=market, session=session)
+                response = await self.client.close_orders_by_market(market=market, selling=selling, session=session)
             logging.info(response)
+            return response
         except Exception as err:
             logging.debug(err)
             raise err
@@ -100,13 +101,23 @@ class OrionXExchange(ExchangeService):
             async with aiohttp.ClientSession() as session:
                 response = await self.client.get_order_status(order_id=order_id, session=session)
             logging.info(response)
-        except Exception as err:
-            logging.debug(err)
-            raise err
+            return response
         except Exception as err:
             logging.debug(err)
             raise Exception("Could not get Order Status")
 
+    async def close_order_by_id(self, order_id: str):
+        try:
+            async with aiohttp.ClientSession() as session:
+                response = await self.client.close_order_by_id(order_id=order_id, session=session)
+            logging.info(response)
+
+            return response
+
+        except Exception as err:
+            logging.debug(err)
+            raise Exception(f"Could not get Cancel Order {order_id}")
+
     async def new_position(
         self,
         market_code: str,
