@@ -148,21 +148,21 @@ class OrionXWalletResponseParser(AbstractResponseParser):
                         "coins": coins,
                         "sign": 1,
                         "time": time.time(),
-                        "date": datetime.now(),
+                        "date": datetime.utcnow(),
                     },
                     {
                         "exchange": "orionX-available",
                         "coins": available,
                         "sign": 0,
                         "time": time.time(),
-                        "date": datetime.now(),
+                        "date": datetime.utcnow(),
                     },
                     {
                         "exchange": "Loans",
                         "coins": loans,
                         "sign": -1,
                         "time": time.time(),
-                        "date": datetime.now(),
+                        "date": datetime.utcnow(),
                     },
                 ],
             )
